// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using System.Collections;

namespace TopCoder.Util.ConfigurationManager
{
    /// <summary>
    /// This enumeration provides values through which the user can
    /// communicate the desired behavior when a namespace or property
    /// collision occurs.
    /// 
    /// Note: collision/clash means having the same name
    /// </summary>
    [Serializable]
    public enum ErrorAction
    {
        /// <summary>
        /// When a namespace/property clash occurs the old namespace/property
        /// should be replaced with the new one.
        /// </summary>
        ReplaceOld = 1,
        
        /// <summary>
        /// When a namespace/property clash occurs the old namespace/property
        /// should be kept and the new one discarded.
        /// </summary>
        KeepOld = 2,
        
        /// <summary>
        /// When a namespace/property clash occurs then the two 
        /// namespaces/properties are merged.
        /// </summary>
        Merge = 3,
        
        /// <summary>
        /// When a namespace/property clash occurs then an appropriate 
        /// exception should be thrown.
        /// </summary>
        ThrowException = 4
    }
}
