// Copyright (c)2005, TopCoder, Inc. All rights reserved
// @author TCSDEVELOPER
// @version 2.0

using System;

namespace TopCoder.Util.ConfigurationManager
{
    /// <summary>
    /// IParsingPreference interface is designed to allow the developer to set 
    /// parsing preferences such as if values should be trimmed before processing, 
    /// if nul/empty values should be allowed, and if an exception should be thrown 
    /// if a property is requested that does not exist and/or is empty, etc. 
    /// And different components within the same app should be able to maintain 
    /// their own preference.
    /// This interface only contains one method to parse the string value according 
    /// to user defined rules. The GetValue/GetValues methods of ConfigManager
    /// will pass the value retrieved to the Parse method to process the string 
    /// first before passing to the client.
    /// </summary>
    public interface IParsingPreference
    {
        /// <summary>
        /// Parses the string value according to user defined rules, and returns 
        /// the processed string to user.  
        /// This method is called by GetValue/GetValues methods of ConfigurationManager
        /// with a IParsingPreference argument to parse the string value retrieved.
        /// </summary>
        /// <param name="val">String to be parsed.</param>
        /// <returns>Parsed string.</returns>
        /// <exception cref="ParsingPreferenceException">
        /// If the string value violates some rule, for example if the string
        /// can not be null and the one passed in is null.
        /// </exception>
        string Parse(string val);
    }
}
