// Copyright (c)2005, TopCoder, Inc. All rights reserved
// @author TCSDEVELOPER
// @version 2.0

using System;

namespace TopCoder.Util.ConfigurationManager
{
    /// <summary>
    /// IStringConverter interface aims to convert the string value into a specific type. 
    /// This interface will be used by the ConfigManager in GetValue/GetValues methods 
    /// to convert string into user specified type. 
    /// If not specified, ConfigManager will use the DefaultStringConverter to do 
    /// the conversion by default, which is an implementation of this interface.
    /// </summary>
    public interface IStringConverter
    {
            /// <summary>
            /// Converts the string to the specified type.
            /// </summary>
            /// <param name="val">Value to be converted.</param>
            /// <param name="type">The type to which val has to be conerted.</param>
            /// <returns>
            /// The value to be converted into the specified type or its subclass.
            /// </returns>
            /// <exception cref="NotSupportedException">
            /// If the string value cannot be converted correctly.
            /// </exception>
            object Convert (string val, Type type);
    }
}
