/*
 * Copyright (c)2005, TopCoder, Inc. All rights reserved
 * @author sinaddcos
 * @version 2.0
 */
using System;
using NUnit.Framework;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager.Test.Accuray
{
	/// <summary>
	/// Test the accuracy of the DefaultStringConverter class.
	/// </summary>
	[TestFixture]
	public class AccuracyTestDefaultStringConverter
	{
        /// <summary>
        /// Enum type for test.
        /// </summary>
        enum Color 
        {
            Red = 1, 
            Green = 2,
            Blue = 3,
            Orange = 4
        }

        /// <summary>
        /// The DefaultStringConverter object used in the test.
        /// </summary>
        private DefaultStringConverter converter = null;

        /// <summary>
        /// Set up environment.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            converter = DefaultStringConverter.Instance;
        }

        /// <summary>
        /// Test the converting string value to various primitive types.
        /// </summary>
        [Test]
        public void TestConvertPrimitiveType()
        {
            Assert.AreEqual(0, converter.Convert("00000000", typeof(int)), "Convert string to Integer 0");
            Assert.AreEqual(-123456789, converter.Convert(" -123456789  ", typeof(int)), "Convert to Integer -123456789");
            Assert.AreEqual(123, converter.Convert(" 123 ", typeof(int)), "Convert 123 to integer 123");
            Assert.AreEqual("123", converter.Convert("123", typeof(string)), "Convert 123 to string itself");
            Assert.AreEqual(123L, converter.Convert("123", typeof(long)), "Convert  123 to long");
            Assert.AreEqual(123.4f, converter.Convert("123.4", typeof(float)), "Convert to float 123.4");
            Assert.AreEqual('a', converter.Convert("a", typeof(char)), "Convert to char a");
        }

        /// <summary>
        /// Test converting string to enums.
        /// </summary>
        [Test]
        public void TestConvertEnumType()
        {
            // Convert string to enum.
            Assert.AreEqual(Color.Blue, (Color) converter.Convert("Blue", typeof(Color)), "Convert to an enum");
        }
	}
}
