// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.UnitTests
{
    /// <summary>
    /// Unit tests for the ConfigFile class
    /// </summary>
    [TestFixture]
    public class ConfigFileUnitTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
            File.Delete(@"..\..\test_files\newtest.ini");
			cm.Clear();
        }

        /// <summary>
        /// Tests the Namespaces field of ConfigFile
        /// </summary>
        [Test]
        public void TestNamespaces()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(2, cf.Namespaces.Length);
            Assertion.AssertEquals("section1", cf.Namespaces[0].Name);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml");
            
            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(1, cf.Namespaces.Length);
            Assertion.AssertEquals("TopCoder.Util.ConfigurationManager.FunctionalTests3", cf.Namespaces[0].Name);

            cm.RemoveFile(@"..\..\test_files\test3.xml");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(1, cf.Namespaces.Length);
            Assertion.AssertEquals("override", cf.Namespaces[0].Name);

            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }

        /// <summary>
        /// Tests the Reload method of ConfigFile
        /// (called from ConfigManager.ReloadFile)
        /// </summary>
        [Test]
        public void TestReload()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            cm.SetValue("section1", "prop2", "newvalue");
            Assertion.AssertEquals("newvalue", cm.GetValue("section1", "prop2"));
            cm.ReloadFile(@"..\..\test_files\test.ini");
            Assertion.AssertEquals("value1", cm.GetValue("section1", "prop2"));

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }

        /// <summary>
        /// Tests the SaveTo method of ConfigFile
        /// (called from ConfigManager.SaveFileTo)
        /// </summary>
        [Test]
        public void TestSaveTo()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            cm.SetValue("section1", "prop2", "newvalue");
            Assertion.AssertEquals("newvalue", cm.GetValue("section1", "prop2"));
            cm.SaveFileTo(@"..\..\test_files\test.ini",@"..\..\test_files\newtest.ini");
            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\newtest.ini");
            Assertion.AssertEquals("newvalue", cm.GetValue("section1", "prop2"));
            cm.RemoveFile(@"..\..\test_files\newtest.ini");

            cf = cm.LoadFile(@"..\..\test_files\test.ini");
            Assertion.AssertEquals("value1", cm.GetValue("section1", "prop2"));
            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
    }
}
