// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author aksonov
// @version 1.0

using System;
using System.Collections;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager.FailureTests
{
    /// <summary>
    /// Test implementation of the ErrorCallback interface that
    /// throws exceptions for all errors.
    /// </summary>
    [Serializable]
    public class MyErrorCallback: ErrorCallback
    {
        /// <summary>
        /// Called in case of a namespace collision to give the
        /// user a chance to choose the action to be taken.
        /// Returns always ErrorAction.ThrowException.
        /// </summary>
        /// <param name="oldNamespace">The old namespace</param>
        /// <param name="newNamespace">The new namespace</param>
        /// <returns>
        /// an ErrorAction enumeration value to specify whether
        /// the old namespace should be kept, the new namespace should
        /// replace the old one, the namespaces should be merged or
        /// an exception should be thrown
        /// </returns>
        public ErrorAction NamespaceCollision(Namespace oldNamespace, 
            Namespace newNamespace)
        {
            return ErrorAction.Merge;  
        }
        
        /// <summary>
        /// Called in case of a property collision to give the
        /// user a chance to choose the action to be taken.
        /// Returns always ErrorAction.ThrowException.
        /// </summary>
        /// <param name="ns">The namespace that holds both properties</param>
        /// <param name="oldProperty">The old property</param>
        /// <param name="newProperty">The new property</param>
        /// <returns>
        /// an ErrorAction enumeration value to specify whether
        /// the old property should be kept, the new property should
        /// replace the old one, the properties should be merged or
        /// an exception should be thrown
        /// </returns>
        public ErrorAction PropertyCollision(Namespace ns, 
            Property oldProperty,
            Property newProperty)
        {
            return ErrorAction.Merge;
        }
        
        /// <summary>
        /// Called in case of a critical error to give the
        /// user a chance to choose the action to be taken.
        /// Returns always true.
        /// </summary>
        /// <param name="exception">The exception that occured</param>
        /// <returns>
        /// a boolean value specifying whether the exception should be
        /// thrown or not (true - throw, false - ignore)
        /// </returns>
        public bool CriticalError(Exception exception)
        {
            return true;
        }
    }
}
