// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.FunctionalTests
{
    /// <summary>
    /// Functional tests for the Load Configuration File use case.
    /// </summary>
    [TestFixture]
    public class LoadConfigurationFileTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
        }

        /// <summary>
        /// Test instantiation.
        /// </summary>
        [Test]
        public void TestInstantiation()
        {
            Assertion.AssertNotNull(cm);
            Namespace[] namespaceObject = cm.Namespaces;
            Assertion.AssertNotNull(namespaceObject);
            Assertion.Assert(namespaceObject.Length == 2);
            Assertion.AssertNotNull(cm.GetNamespace(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1"));
            Assertion.AssertNotNull(cm.GetNamespace(
                "TopCoder.Util.ConfigurationManager.FunctionalTests2"));
        }
        
        /// <summary>
        /// Test loading an XML file.
        /// </summary>
        [Test]
        public void TestLoadingXml()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test3.xml");
            Namespace[] namespaceObject = cf.Namespaces;
            Assertion.AssertNotNull(namespaceObject);
            Assertion.Assert(namespaceObject.Length == 1);
            Assertion.AssertNotNull(cm.GetNamespace(
                "TopCoder.Util.ConfigurationManager.FunctionalTests3"));
            String[] values = cm.GetValues(
                "TopCoder.Util.ConfigurationManager.FunctionalTests3", "p1");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 2);
            Assertion.Assert(values[0].Equals("v1") && values[1].Equals("v2"));
            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }
        
        /// <summary>
        /// Test loading an XML file.
        /// </summary>
        [Test]
        public void TestLoadingIni()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            Namespace[] namespaceObject = cf.Namespaces;
            Assertion.AssertNotNull(namespaceObject);
            Assertion.Assert(namespaceObject.Length == 2);
            Assertion.AssertNotNull(cm.GetNamespace("section1"));
            Assertion.AssertNotNull(cm.GetNamespace("section2"));
            
            String[] values = cm.GetValues("section1", "prop1");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 1);
            Assertion.Assert(values[0].Equals("value1"));
            
            values = cm.GetValues("section1", "prop2");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 2);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2"));
            
            values = cm.GetValues("section1", "prop3");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 3);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2") && 
                             values[2].Equals("value3"));
            
            values = cm.GetValues("section2", "prop1");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 1);
            Assertion.Assert(values[0].Equals("value1"));
            
            values = cm.GetValues("section2", "prop2");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 2);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2"));
            
            values = cm.GetValues("section2", "prop3");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 3);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2") && 
                             values[2].Equals("value3"));
            
            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
    }
}
